@@ -1,4 +1,4 @@
-import '@heartex/datamanager/build/static/css/main.css';
+// import '@heartex/datamanager/build/static/css/main.css';
 import { DataManager } from "../../dm/js/main";
 
 const dmRoot = document.querySelector(".datamanager");
