@@ -2,6 +2,8 @@ from .base import create_storage, register_storage, get_available_storage_names,
 from .filesystem import JSONStorage, DirJSONsStorage, TasksJSONStorage, CompletionsDirStorage, ExternalTasksJSONStorage
 from .s3 import S3Storage, S3CompletionsStorage
 from .gcs import GCSStorage, GCSCompletionsStorage
+from .redis import RedisStorage, RedisCompletionsStorage
+from .azure_blob import AzureBlobStorage, AzureBlobCompletionsStorage
 
 register_storage('json', JSONStorage)
 register_storage('dir-jsons', DirJSONsStorage)
@@ -11,3 +13,7 @@ register_storage('s3', S3Storage)
 register_storage('s3-completions', S3CompletionsStorage)
 register_storage('gcs', GCSStorage)
 register_storage('gcs-completions', GCSCompletionsStorage)
+register_storage('redis', RedisStorage)
+register_storage('redis-completions', RedisCompletionsStorage)
+register_storage('azure-blob', AzureBlobStorage)
+register_storage('azure-blob-completions', AzureBlobCompletionsStorage)
\ No newline at end of file
