@@ -1,5 +1,6 @@
 import logging
 import os
+import sys
 import io
 import requests
 import calendar
@@ -102,6 +103,8 @@ class Analytics(object):
             return True
         if request.args.get('polling', False):
             return True
+        if request.args.get('interaction', None) == 'timer':
+            return True
 
     def send(self, request=None, session=None, response=None, **kwargs):
         if not self.collect_analytics:
@@ -132,7 +135,8 @@ class Analytics(object):
                 'content_length': request.content_length,
                 'env': self.env,
                 'version': self.version,
-                'project_name': self.input_args.project_name if self.input_args else None
+                'project_name': self.input_args.project_name if self.input_args else None,
+                'python': str(sys.version_info[0]) + '.' + str(sys.version_info[1])
             }
         except:
             pass
